import * as msRest from "@azure/ms-rest-js";
import * as Models from "./models";
import * as Mappers from "./models/mappers";
import * as operations from "./operations";
import { AzureReservationAPIContext } from "./azureReservationAPIContext";
declare class AzureReservationAPI extends AzureReservationAPIContext {
    quota: operations.Quota;
    quotaRequestStatus: operations.QuotaRequestStatus;
    autoQuotaIncrease: operations.AutoQuotaIncrease;
    reservation: operations.Reservation;
    reservationOrder: operations.ReservationOrder;
    operation: operations.Operation;
    /**
     * Initializes a new instance of the AzureReservationAPI class.
     * @param credentials Credentials needed for the client to connect to Azure.
     * @param [options] The parameter options
     */
    constructor(credentials: msRest.ServiceClientCredentials, options?: Models.AzureReservationAPIOptions);
    /**
     * @summary Get the regions and skus that are available for RI purchase for the specified Azure
     * subscription.
     * @param subscriptionId Id of the subscription
     * @param reservedResourceType The type of the resource for which the skus should be provided.
     * @param [options] The optional parameters
     * @returns Promise<Models.GetCatalogResponse>
     */
    getCatalog(subscriptionId: string, reservedResourceType: string, options?: Models.AzureReservationAPIGetCatalogOptionalParams): Promise<Models.GetCatalogResponse>;
    /**
     * @param subscriptionId Id of the subscription
     * @param reservedResourceType The type of the resource for which the skus should be provided.
     * @param callback The callback
     */
    getCatalog(subscriptionId: string, reservedResourceType: string, callback: msRest.ServiceCallback<Models.Catalog[]>): void;
    /**
     * @param subscriptionId Id of the subscription
     * @param reservedResourceType The type of the resource for which the skus should be provided.
     * @param options The optional parameters
     * @param callback The callback
     */
    getCatalog(subscriptionId: string, reservedResourceType: string, options: Models.AzureReservationAPIGetCatalogOptionalParams, callback: msRest.ServiceCallback<Models.Catalog[]>): void;
    /**
     * Get applicable `Reservation`s that are applied to this subscription or a resource group under
     * this subscription.
     * @summary Get list of applicable `Reservation`s.
     * @param subscriptionId Id of the subscription
     * @param [options] The optional parameters
     * @returns Promise<Models.GetAppliedReservationListResponse>
     */
    getAppliedReservationList(subscriptionId: string, options?: msRest.RequestOptionsBase): Promise<Models.GetAppliedReservationListResponse>;
    /**
     * @param subscriptionId Id of the subscription
     * @param callback The callback
     */
    getAppliedReservationList(subscriptionId: string, callback: msRest.ServiceCallback<Models.AppliedReservations>): void;
    /**
     * @param subscriptionId Id of the subscription
     * @param options The optional parameters
     * @param callback The callback
     */
    getAppliedReservationList(subscriptionId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AppliedReservations>): void;
}
export { AzureReservationAPI, AzureReservationAPIContext, Models as AzureReservationAPIModels, Mappers as AzureReservationAPIMappers };
export * from "./operations";
//# sourceMappingURL=azureReservationAPI.d.ts.map