import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { AzureReservationAPIContext } from "../azureReservationAPIContext";
/** Class representing a Quota. */
export declare class Quota {
    private readonly client;
    /**
     * Create a Quota.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    constructor(client: AzureReservationAPIContext);
    /**
     * Gets the current service limits (quotas) and usage of a resource. The response from Get API can
     * be leveraged to submit quota update requests.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaGetResponse>
     */
    get(subscriptionId: string, providerId: string, location: string, resourceName: string, options?: msRest.RequestOptionsBase): Promise<Models.QuotaGetResponse>;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param callback The callback
     */
    get(subscriptionId: string, providerId: string, location: string, resourceName: string, callback: msRest.ServiceCallback<Models.CurrentQuotaLimitBase>): void;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param options The optional parameters
     * @param callback The callback
     */
    get(subscriptionId: string, providerId: string, location: string, resourceName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CurrentQuotaLimitBase>): void;
    /**
     * Create or update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Create quota request may be constructed as follows. The PUT operation can be used to update
     * the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaCreateOrUpdateResponse>
     */
    createOrUpdate(subscriptionId: string, providerId: string, location: string, resourceName: string, createQuotaRequest: Models.CurrentQuotaLimitBase, options?: msRest.RequestOptionsBase): Promise<Models.QuotaCreateOrUpdateResponse>;
    /**
     * Update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Update quota request may be constructed as follows. The PATCH operation can be used to
     * update the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaUpdateResponse>
     */
    update(subscriptionId: string, providerId: string, location: string, resourceName: string, createQuotaRequest: Models.CurrentQuotaLimitBase, options?: msRest.RequestOptionsBase): Promise<Models.QuotaUpdateResponse>;
    /**
     * Get a list of current service limits (quota) and usages of all the resources. The response from
     * List API can be leveraged to submit quota update requests.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaListResponse>
     */
    list(subscriptionId: string, providerId: string, location: string, options?: msRest.RequestOptionsBase): Promise<Models.QuotaListResponse>;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param callback The callback
     */
    list(subscriptionId: string, providerId: string, location: string, callback: msRest.ServiceCallback<Models.QuotaLimits>): void;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(subscriptionId: string, providerId: string, location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.QuotaLimits>): void;
    /**
     * Create or update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Create quota request may be constructed as follows. The PUT operation can be used to update
     * the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(subscriptionId: string, providerId: string, location: string, resourceName: string, createQuotaRequest: Models.CurrentQuotaLimitBase, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Update quota request may be constructed as follows. The PATCH operation can be used to
     * update the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(subscriptionId: string, providerId: string, location: string, resourceName: string, createQuotaRequest: Models.CurrentQuotaLimitBase, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Get a list of current service limits (quota) and usages of all the resources. The response from
     * List API can be leveraged to submit quota update requests.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaListResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.QuotaListResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.QuotaLimits>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.QuotaLimits>): void;
}
//# sourceMappingURL=quota.d.ts.map