/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/quotaMappers";
import * as Parameters from "../models/parameters";
/** Class representing a Quota. */
var Quota = /** @class */ (function () {
    /**
     * Create a Quota.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    function Quota(client) {
        this.client = client;
    }
    Quota.prototype.get = function (subscriptionId, providerId, location, resourceName, options, callback) {
        return this.client.sendOperationRequest({
            subscriptionId: subscriptionId,
            providerId: providerId,
            location: location,
            resourceName: resourceName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Create or update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Create quota request may be constructed as follows. The PUT operation can be used to update
     * the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaCreateOrUpdateResponse>
     */
    Quota.prototype.createOrUpdate = function (subscriptionId, providerId, location, resourceName, createQuotaRequest, options) {
        return this.beginCreateOrUpdate(subscriptionId, providerId, location, resourceName, createQuotaRequest, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Update quota request may be constructed as follows. The PATCH operation can be used to
     * update the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaUpdateResponse>
     */
    Quota.prototype.update = function (subscriptionId, providerId, location, resourceName, createQuotaRequest, options) {
        return this.beginUpdate(subscriptionId, providerId, location, resourceName, createQuotaRequest, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Quota.prototype.list = function (subscriptionId, providerId, location, options, callback) {
        return this.client.sendOperationRequest({
            subscriptionId: subscriptionId,
            providerId: providerId,
            location: location,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Create or update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Create quota request may be constructed as follows. The PUT operation can be used to update
     * the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Quota.prototype.beginCreateOrUpdate = function (subscriptionId, providerId, location, resourceName, createQuotaRequest, options) {
        return this.client.sendLRORequest({
            subscriptionId: subscriptionId,
            providerId: providerId,
            location: location,
            resourceName: resourceName,
            createQuotaRequest: createQuotaRequest,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Update the service limits (quota) of a resource to requested value.
     * Steps:
     *
     * 1. Make the Get request to get the quota information for specific resource.
     *
     * 2. To increase the quota, update the limit field in the response from Get request to new value.
     *
     * 3. Submit the JSON to the quota request API to update the quota.
     * The Update quota request may be constructed as follows. The PATCH operation can be used to
     * update the quota.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param resourceName The resource name for a resource provider, such as SKU name for
     * Microsoft.Compute, Sku or TotalLowPriorityCores for Microsoft.MachineLearningServices
     * @param createQuotaRequest Quota requests payload.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Quota.prototype.beginUpdate = function (subscriptionId, providerId, location, resourceName, createQuotaRequest, options) {
        return this.client.sendLRORequest({
            subscriptionId: subscriptionId,
            providerId: providerId,
            location: location,
            resourceName: resourceName,
            createQuotaRequest: createQuotaRequest,
            options: options
        }, beginUpdateOperationSpec, options);
    };
    Quota.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return Quota;
}());
export { Quota };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Capacity/resourceProviders/{providerId}/locations/{location}/serviceLimits/{resourceName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.providerId,
        Parameters.location0,
        Parameters.resourceName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.CurrentQuotaLimitBase,
            headersMapper: Mappers.QuotaGetHeaders
        },
        default: {
            bodyMapper: Mappers.ExceptionResponse
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Capacity/resourceProviders/{providerId}/locations/{location}/serviceLimits",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.providerId,
        Parameters.location0
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.QuotaLimits,
            headersMapper: Mappers.QuotaListHeaders
        },
        default: {
            bodyMapper: Mappers.ExceptionResponse
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Capacity/resourceProviders/{providerId}/locations/{location}/serviceLimits/{resourceName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.providerId,
        Parameters.location0,
        Parameters.resourceName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "createQuotaRequest",
        mapper: __assign(__assign({}, Mappers.CurrentQuotaLimitBase), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.QuotaRequestOneResourceSubmitResponse
        },
        201: {
            bodyMapper: Mappers.QuotaRequestSubmitResponse201
        },
        default: {
            bodyMapper: Mappers.ExceptionResponse
        }
    },
    serializer: serializer
};
var beginUpdateOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Capacity/resourceProviders/{providerId}/locations/{location}/serviceLimits/{resourceName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.providerId,
        Parameters.location0,
        Parameters.resourceName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "createQuotaRequest",
        mapper: __assign(__assign({}, Mappers.CurrentQuotaLimitBase), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.QuotaRequestOneResourceSubmitResponse
        },
        201: {
            bodyMapper: Mappers.QuotaRequestSubmitResponse201
        },
        default: {
            bodyMapper: Mappers.ExceptionResponse
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.QuotaLimits,
            headersMapper: Mappers.QuotaListHeaders
        },
        default: {
            bodyMapper: Mappers.ExceptionResponse
        }
    },
    serializer: serializer
};
//# sourceMappingURL=quota.js.map