import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { AzureReservationAPIContext } from "../azureReservationAPIContext";
/** Class representing a QuotaRequestStatus. */
export declare class QuotaRequestStatus {
    private readonly client;
    /**
     * Create a QuotaRequestStatus.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    constructor(client: AzureReservationAPIContext);
    /**
     * Gets the QuotaRequest details and status by the quota request Id for the resources for the
     * resource provider at a specific location. The requestId is returned as response to the Put
     * requests for serviceLimits.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param id Quota Request id.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaRequestStatusGetResponse>
     */
    get(subscriptionId: string, providerId: string, location: string, id: string, options?: msRest.RequestOptionsBase): Promise<Models.QuotaRequestStatusGetResponse>;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param id Quota Request id.
     * @param callback The callback
     */
    get(subscriptionId: string, providerId: string, location: string, id: string, callback: msRest.ServiceCallback<Models.QuotaRequestDetails>): void;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param id Quota Request id.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(subscriptionId: string, providerId: string, location: string, id: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.QuotaRequestDetails>): void;
    /**
     * For the specified location and Resource provider gets the current quota requests under the
     * subscription over the time period of one year ago from now to one year back. oData filter can be
     * used to select quota requests.
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaRequestStatusListResponse>
     */
    list(subscriptionId: string, providerId: string, location: string, options?: Models.QuotaRequestStatusListOptionalParams): Promise<Models.QuotaRequestStatusListResponse>;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param callback The callback
     */
    list(subscriptionId: string, providerId: string, location: string, callback: msRest.ServiceCallback<Models.QuotaRequestDetailsList>): void;
    /**
     * @param subscriptionId Azure subscription id.
     * @param providerId Azure resource provider id.
     * @param location Azure region.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(subscriptionId: string, providerId: string, location: string, options: Models.QuotaRequestStatusListOptionalParams, callback: msRest.ServiceCallback<Models.QuotaRequestDetailsList>): void;
    /**
     * For the specified location and Resource provider gets the current quota requests under the
     * subscription over the time period of one year ago from now to one year back. oData filter can be
     * used to select quota requests.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.QuotaRequestStatusListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.QuotaRequestStatusListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.QuotaRequestDetailsList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.QuotaRequestDetailsList>): void;
}
//# sourceMappingURL=quotaRequestStatus.d.ts.map