import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { AzureReservationAPIContext } from "../azureReservationAPIContext";
/** Class representing a Reservation. */
export declare class Reservation {
    private readonly client;
    /**
     * Create a Reservation.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    constructor(client: AzureReservationAPIContext);
    /**
     * Get Available Scopes for `Reservation`.
     * @summary Get Available Scopes for `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationAvailableScopesResponse>
     */
    availableScopes(reservationOrderId: string, reservationId: string, body: string[], options?: msRest.RequestOptionsBase): Promise<Models.ReservationAvailableScopesResponse>;
    /**
     * Split a `Reservation` into two `Reservation`s with specified quantity distribution.
     * @summary Split the `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed to Split a reservation item
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationSplitResponse>
     */
    split(reservationOrderId: string, body: Models.SplitRequest, options?: msRest.RequestOptionsBase): Promise<Models.ReservationSplitResponse>;
    /**
     * Merge the specified `Reservation`s into a new `Reservation`. The two `Reservation`s being merged
     * must have same properties.
     * @summary Merges two `Reservation`s.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for commercial request for a reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationMergeResponse>
     */
    merge(reservationOrderId: string, body: Models.MergeRequest, options?: msRest.RequestOptionsBase): Promise<Models.ReservationMergeResponse>;
    /**
     * List `Reservation`s within a single `ReservationOrder`.
     * @summary Get `Reservation`s in a given reservation Order
     * @param reservationOrderId Order Id of the reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationListResponse>
     */
    list(reservationOrderId: string, options?: msRest.RequestOptionsBase): Promise<Models.ReservationListResponse>;
    /**
     * @param reservationOrderId Order Id of the reservation
     * @param callback The callback
     */
    list(reservationOrderId: string, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * @param reservationOrderId Order Id of the reservation
     * @param options The optional parameters
     * @param callback The callback
     */
    list(reservationOrderId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * Get specific `Reservation` details.
     * @summary Get `Reservation` details.
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationGetResponse>
     */
    get(reservationId: string, reservationOrderId: string, options?: Models.ReservationGetOptionalParams): Promise<Models.ReservationGetResponse>;
    /**
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param callback The callback
     */
    get(reservationId: string, reservationOrderId: string, callback: msRest.ServiceCallback<Models.ReservationResponse>): void;
    /**
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param options The optional parameters
     * @param callback The callback
     */
    get(reservationId: string, reservationOrderId: string, options: Models.ReservationGetOptionalParams, callback: msRest.ServiceCallback<Models.ReservationResponse>): void;
    /**
     * Updates the applied scopes of the `Reservation`.
     * @summary Updates a `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param parameters Information needed to patch a reservation item
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationUpdateResponse>
     */
    update(reservationOrderId: string, reservationId: string, parameters: Models.Patch, options?: msRest.RequestOptionsBase): Promise<Models.ReservationUpdateResponse>;
    /**
     * List of all the revisions for the `Reservation`.
     * @summary Get `Reservation` revisions.
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationListRevisionsResponse>
     */
    listRevisions(reservationId: string, reservationOrderId: string, options?: msRest.RequestOptionsBase): Promise<Models.ReservationListRevisionsResponse>;
    /**
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param callback The callback
     */
    listRevisions(reservationId: string, reservationOrderId: string, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * @param reservationId Id of the Reservation Item
     * @param reservationOrderId Order Id of the reservation
     * @param options The optional parameters
     * @param callback The callback
     */
    listRevisions(reservationId: string, reservationOrderId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * Get Available Scopes for `Reservation`.
     * @summary Get Available Scopes for `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginAvailableScopes(reservationOrderId: string, reservationId: string, body: string[], options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Split a `Reservation` into two `Reservation`s with specified quantity distribution.
     * @summary Split the `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed to Split a reservation item
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginSplit(reservationOrderId: string, body: Models.SplitRequest, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Merge the specified `Reservation`s into a new `Reservation`. The two `Reservation`s being merged
     * must have same properties.
     * @summary Merges two `Reservation`s.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for commercial request for a reservation
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginMerge(reservationOrderId: string, body: Models.MergeRequest, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Updates the applied scopes of the `Reservation`.
     * @summary Updates a `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param parameters Information needed to patch a reservation item
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(reservationOrderId: string, reservationId: string, parameters: Models.Patch, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * List `Reservation`s within a single `ReservationOrder`.
     * @summary Get `Reservation`s in a given reservation Order
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.ReservationListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * List of all the revisions for the `Reservation`.
     * @summary Get `Reservation` revisions.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationListRevisionsNextResponse>
     */
    listRevisionsNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.ReservationListRevisionsNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listRevisionsNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ReservationList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listRevisionsNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationList>): void;
}
//# sourceMappingURL=reservation.d.ts.map