/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/reservationMappers";
import * as Parameters from "../models/parameters";
/** Class representing a Reservation. */
var Reservation = /** @class */ (function () {
    /**
     * Create a Reservation.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    function Reservation(client) {
        this.client = client;
    }
    /**
     * Get Available Scopes for `Reservation`.
     * @summary Get Available Scopes for `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationAvailableScopesResponse>
     */
    Reservation.prototype.availableScopes = function (reservationOrderId, reservationId, body, options) {
        return this.beginAvailableScopes(reservationOrderId, reservationId, body, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Split a `Reservation` into two `Reservation`s with specified quantity distribution.
     * @summary Split the `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed to Split a reservation item
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationSplitResponse>
     */
    Reservation.prototype.split = function (reservationOrderId, body, options) {
        return this.beginSplit(reservationOrderId, body, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Merge the specified `Reservation`s into a new `Reservation`. The two `Reservation`s being merged
     * must have same properties.
     * @summary Merges two `Reservation`s.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for commercial request for a reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationMergeResponse>
     */
    Reservation.prototype.merge = function (reservationOrderId, body, options) {
        return this.beginMerge(reservationOrderId, body, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Reservation.prototype.list = function (reservationOrderId, options, callback) {
        return this.client.sendOperationRequest({
            reservationOrderId: reservationOrderId,
            options: options
        }, listOperationSpec, callback);
    };
    Reservation.prototype.get = function (reservationId, reservationOrderId, options, callback) {
        return this.client.sendOperationRequest({
            reservationId: reservationId,
            reservationOrderId: reservationOrderId,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Updates the applied scopes of the `Reservation`.
     * @summary Updates a `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param parameters Information needed to patch a reservation item
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationUpdateResponse>
     */
    Reservation.prototype.update = function (reservationOrderId, reservationId, parameters, options) {
        return this.beginUpdate(reservationOrderId, reservationId, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    Reservation.prototype.listRevisions = function (reservationId, reservationOrderId, options, callback) {
        return this.client.sendOperationRequest({
            reservationId: reservationId,
            reservationOrderId: reservationOrderId,
            options: options
        }, listRevisionsOperationSpec, callback);
    };
    /**
     * Get Available Scopes for `Reservation`.
     * @summary Get Available Scopes for `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Reservation.prototype.beginAvailableScopes = function (reservationOrderId, reservationId, body, options) {
        return this.client.sendLRORequest({
            reservationOrderId: reservationOrderId,
            reservationId: reservationId,
            body: body,
            options: options
        }, beginAvailableScopesOperationSpec, options);
    };
    /**
     * Split a `Reservation` into two `Reservation`s with specified quantity distribution.
     * @summary Split the `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed to Split a reservation item
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Reservation.prototype.beginSplit = function (reservationOrderId, body, options) {
        return this.client.sendLRORequest({
            reservationOrderId: reservationOrderId,
            body: body,
            options: options
        }, beginSplitOperationSpec, options);
    };
    /**
     * Merge the specified `Reservation`s into a new `Reservation`. The two `Reservation`s being merged
     * must have same properties.
     * @summary Merges two `Reservation`s.
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for commercial request for a reservation
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Reservation.prototype.beginMerge = function (reservationOrderId, body, options) {
        return this.client.sendLRORequest({
            reservationOrderId: reservationOrderId,
            body: body,
            options: options
        }, beginMergeOperationSpec, options);
    };
    /**
     * Updates the applied scopes of the `Reservation`.
     * @summary Updates a `Reservation`.
     * @param reservationOrderId Order Id of the reservation
     * @param reservationId Id of the Reservation Item
     * @param parameters Information needed to patch a reservation item
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    Reservation.prototype.beginUpdate = function (reservationOrderId, reservationId, parameters, options) {
        return this.client.sendLRORequest({
            reservationOrderId: reservationOrderId,
            reservationId: reservationId,
            parameters: parameters,
            options: options
        }, beginUpdateOperationSpec, options);
    };
    Reservation.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    Reservation.prototype.listRevisionsNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listRevisionsNextOperationSpec, callback);
    };
    return Reservation;
}());
export { Reservation };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/reservations",
    urlParameters: [
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/reservations/{reservationId}",
    urlParameters: [
        Parameters.reservationId,
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1,
        Parameters.expand0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationResponse
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listRevisionsOperationSpec = {
    httpMethod: "GET",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/reservations/{reservationId}/revisions",
    urlParameters: [
        Parameters.reservationId,
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginAvailableScopesOperationSpec = {
    httpMethod: "POST",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/reservations/{reservationId}/availableScopes",
    urlParameters: [
        Parameters.reservationOrderId,
        Parameters.reservationId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "body",
        mapper: {
            required: true,
            serializedName: "body",
            type: {
                name: "Sequence",
                element: {
                    type: {
                        name: "String"
                    }
                }
            }
        }
    },
    responses: {
        200: {
            bodyMapper: Mappers.Properties
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginSplitOperationSpec = {
    httpMethod: "POST",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/split",
    urlParameters: [
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "body",
        mapper: __assign(__assign({}, Mappers.SplitRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "Composite",
                            className: "ReservationResponse"
                        }
                    }
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginMergeOperationSpec = {
    httpMethod: "POST",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/merge",
    urlParameters: [
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "body",
        mapper: __assign(__assign({}, Mappers.MergeRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "Sequence",
                    element: {
                        type: {
                            name: "Composite",
                            className: "ReservationResponse"
                        }
                    }
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginUpdateOperationSpec = {
    httpMethod: "PATCH",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}/reservations/{reservationId}",
    urlParameters: [
        Parameters.reservationOrderId,
        Parameters.reservationId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.Patch), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ReservationResponse
        },
        202: {},
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listRevisionsNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
//# sourceMappingURL=reservation.js.map