import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { AzureReservationAPIContext } from "../azureReservationAPIContext";
/** Class representing a ReservationOrder. */
export declare class ReservationOrder {
    private readonly client;
    /**
     * Create a ReservationOrder.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    constructor(client: AzureReservationAPIContext);
    /**
     * Calculate price for placing a `ReservationOrder`.
     * @summary Calculate price for a `ReservationOrder`.
     * @param body Information needed for calculate or purchase reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderCalculateResponse>
     */
    calculate(body: Models.PurchaseRequest, options?: msRest.RequestOptionsBase): Promise<Models.ReservationOrderCalculateResponse>;
    /**
     * @param body Information needed for calculate or purchase reservation
     * @param callback The callback
     */
    calculate(body: Models.PurchaseRequest, callback: msRest.ServiceCallback<Models.CalculatePriceResponse>): void;
    /**
     * @param body Information needed for calculate or purchase reservation
     * @param options The optional parameters
     * @param callback The callback
     */
    calculate(body: Models.PurchaseRequest, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CalculatePriceResponse>): void;
    /**
     * List of all the `ReservationOrder`s that the user has access to in the current tenant.
     * @summary Get all `ReservationOrder`s.
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderListResponse>
     */
    list(options?: msRest.RequestOptionsBase): Promise<Models.ReservationOrderListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.ReservationOrderList>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationOrderList>): void;
    /**
     * Purchase `ReservationOrder` and create resource under the specified URI.
     * @summary Purchase `ReservationOrder`
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for calculate or purchase reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderPurchaseResponse>
     */
    purchase(reservationOrderId: string, body: Models.PurchaseRequest, options?: msRest.RequestOptionsBase): Promise<Models.ReservationOrderPurchaseResponse>;
    /**
     * Get the details of the `ReservationOrder`.
     * @summary Get a specific `ReservationOrder`.
     * @param reservationOrderId Order Id of the reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderGetResponse>
     */
    get(reservationOrderId: string, options?: Models.ReservationOrderGetOptionalParams): Promise<Models.ReservationOrderGetResponse>;
    /**
     * @param reservationOrderId Order Id of the reservation
     * @param callback The callback
     */
    get(reservationOrderId: string, callback: msRest.ServiceCallback<Models.ReservationOrderResponse>): void;
    /**
     * @param reservationOrderId Order Id of the reservation
     * @param options The optional parameters
     * @param callback The callback
     */
    get(reservationOrderId: string, options: Models.ReservationOrderGetOptionalParams, callback: msRest.ServiceCallback<Models.ReservationOrderResponse>): void;
    /**
     * Purchase `ReservationOrder` and create resource under the specified URI.
     * @summary Purchase `ReservationOrder`
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for calculate or purchase reservation
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginPurchase(reservationOrderId: string, body: Models.PurchaseRequest, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * List of all the `ReservationOrder`s that the user has access to in the current tenant.
     * @summary Get all `ReservationOrder`s.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.ReservationOrderListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ReservationOrderList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ReservationOrderList>): void;
}
//# sourceMappingURL=reservationOrder.d.ts.map