/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/reservationOrderMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ReservationOrder. */
var ReservationOrder = /** @class */ (function () {
    /**
     * Create a ReservationOrder.
     * @param {AzureReservationAPIContext} client Reference to the service client.
     */
    function ReservationOrder(client) {
        this.client = client;
    }
    ReservationOrder.prototype.calculate = function (body, options, callback) {
        return this.client.sendOperationRequest({
            body: body,
            options: options
        }, calculateOperationSpec, callback);
    };
    ReservationOrder.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Purchase `ReservationOrder` and create resource under the specified URI.
     * @summary Purchase `ReservationOrder`
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for calculate or purchase reservation
     * @param [options] The optional parameters
     * @returns Promise<Models.ReservationOrderPurchaseResponse>
     */
    ReservationOrder.prototype.purchase = function (reservationOrderId, body, options) {
        return this.beginPurchase(reservationOrderId, body, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ReservationOrder.prototype.get = function (reservationOrderId, options, callback) {
        return this.client.sendOperationRequest({
            reservationOrderId: reservationOrderId,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Purchase `ReservationOrder` and create resource under the specified URI.
     * @summary Purchase `ReservationOrder`
     * @param reservationOrderId Order Id of the reservation
     * @param body Information needed for calculate or purchase reservation
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ReservationOrder.prototype.beginPurchase = function (reservationOrderId, body, options) {
        return this.client.sendLRORequest({
            reservationOrderId: reservationOrderId,
            body: body,
            options: options
        }, beginPurchaseOperationSpec, options);
    };
    ReservationOrder.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ReservationOrder;
}());
export { ReservationOrder };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var calculateOperationSpec = {
    httpMethod: "POST",
    path: "providers/Microsoft.Capacity/calculatePrice",
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "body",
        mapper: __assign(__assign({}, Mappers.PurchaseRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.CalculatePriceResponse
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "providers/Microsoft.Capacity/reservationOrders",
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationOrderList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}",
    urlParameters: [
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1,
        Parameters.expand1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationOrderResponse
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var beginPurchaseOperationSpec = {
    httpMethod: "PUT",
    path: "providers/Microsoft.Capacity/reservationOrders/{reservationOrderId}",
    urlParameters: [
        Parameters.reservationOrderId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "body",
        mapper: __assign(__assign({}, Mappers.PurchaseRequest), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ReservationOrderResponse
        },
        202: {
            bodyMapper: Mappers.ReservationOrderResponse
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ReservationOrderList
        },
        default: {
            bodyMapper: Mappers.ErrorModel
        }
    },
    serializer: serializer
};
//# sourceMappingURL=reservationOrder.js.map